<?php
	if ( ! defined( 'ABSPATH' ) ) {
		exit; // Exit if accessed directly.
	}

	class ZLEADSCRM_EXPORT_Core_Admin {
		public function __construct() {
			add_action( 'plugins_loaded', array( $this, 'init_hooks' ), 60 );
		}


		public function init_hooks() {
			if ( ! class_exists( 'ZLEADSCRM_BASIC_Core' ) ) {
				add_action( 'admin_notices', function () {
					?>
                    <div class="notice notice-error is-dismissible">
                        <p>To be able to use Leads Export Add-on, you need to install the Leads Basic Plugin
                            first!</p>
                    </div>
					<?php

				} );

				return;
			}


			add_action( 'admin_init', array( $this, 'admin_init' ) );

			/* Form Post */
			add_action( 'admin_post_zleadscrm_edit_settings', array( $this, 'edit_settings' ), 20 );

		}

		public function admin_init() {
		}

		public function edit_settings() {
			if ( ! isset( $_POST['_wpnonce'] ) || ! wp_verify_nonce( $_POST['_wpnonce'], 'zleadscrm_edit_settings' ) ) {
				wp_redirect( 'admin.php?page=zleadscrm_settings' );
				exit();
			}

			if ( isset( $_POST['zleadscrm_users_allowed_export_search_setting'] ) ) {
				update_option( 'zleadscrm_users_allowed_export_search_setting', sanitize_text_field( $_POST['zleadscrm_users_allowed_export_search_setting'] ) );
			}

			if ( isset( $_POST['zleadscrm_allowed_export_search_users'] ) ) {
				update_option( 'zleadscrm_allowed_export_search_users', zleadscrm_sanitize_array( $_POST['zleadscrm_allowed_export_search_users'] ) );
			}

			if ( isset( $_POST['zleadscrm_users_allowed_export_leads_setting'] ) ) {
				update_option( 'zleadscrm_users_allowed_export_leads_setting', sanitize_text_field( $_POST['zleadscrm_users_allowed_export_leads_setting'] ) );
			}

			if ( isset( $_POST['zleadscrm_allowed_export_leads_users'] ) ) {
				update_option( 'zleadscrm_allowed_export_leads_users', zleadscrm_sanitize_array( $_POST['zleadscrm_allowed_export_leads_users'] ) );
			}

			if ( isset( $_POST['zleadscrm_users_allowed_export_bookmarks_setting'] ) ) {
				update_option( 'zleadscrm_users_allowed_export_bookmarks_setting', sanitize_text_field( $_POST['zleadscrm_users_allowed_export_bookmarks_setting'] ) );
			}

			if ( isset( $_POST['zleadscrm_allowed_export_bookmarks_users'] ) ) {
				update_option( 'zleadscrm_allowed_export_bookmarks_users', zleadscrm_sanitize_array( $_POST['zleadscrm_allowed_export_bookmarks_users'] ) );
			}

			if ( ! class_exists( 'ZLEADSCRM_PROSPECT_Core' ) && ! class_exists( 'ZLEADSCRM_PIPELINE_Core' ) ) {
				wp_redirect( 'admin.php?page=zleadscrm_settings&_wpnonce=' . $_POST['_wpnonce'] );
				exit();
			}
		}

		public function ajax_search_admins() {
			$managers = array();
			$data     = array();

			if ( isset( $_REQUEST['search'] ) ) {
				$search = sanitize_text_field( $_REQUEST['search'] );

				$query    = zleadscrm_get_admins_query_by_key( $search );
				$managers = $query->get_results();
				if ( $managers && count( $managers ) > 0 ) {
					foreach ( $managers as $manager ) {
						$temp['id']         = $manager->ID;
						$temp['first_name'] = $manager->first_name;
						$temp['last_name']  = $manager->last_name;

						$data[] = $temp;
					}
				}
			} else {
				$query    = zleadscrm_get_admins_query_by_key();
				$managers = $query->get_results();

				if ( $managers && count( $managers ) > 0 ) {
					foreach ( $managers as $manager ) {
						$temp['id']         = $manager->ID;
						$temp['first_name'] = $manager->first_name;
						$temp['last_name']  = $manager->last_name;

						$data[] = $temp;
					}
				}
			}

			exit( json_encode( $data ) );
		}

	}

?>